==> paraview-5.12.1-9-x86_64.pkg.tar.zst: opt/paraview/lib/cmake/paraview/LANLX3DReader-vtk-module-properties.cmake <==
set(_vtk_module_import_prefix "${CMAKE_CURRENT_LIST_DIR}")
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
set_property(TARGET "LANLX3DReader::vtkLANLX3DReader" PROPERTY "INTERFACE_vtk_module_exclude_wrap" "FALSE")
set_property(TARGET "LANLX3DReader::vtkLANLX3DReader" PROPERTY "INTERFACE_vtk_module_depends" "VTK::FiltersCore")
set_property(TARGET "LANLX3DReader::vtkLANLX3DReader" PROPERTY "INTERFACE_vtk_module_private_depends" "VTK::CommonCore")
set_property(TARGET "LANLX3DReader::vtkLANLX3DReader" PROPERTY "INTERFACE_vtk_module_optional_depends" "")
set_property(TARGET "LANLX3DReader::vtkLANLX3DReader" PROPERTY "INTERFACE_vtk_module_implements" "")
set_property(TARGET "LANLX3DReader::vtkLANLX3DReader" PROPERTY "INTERFACE_vtk_module_implementable" "FALSE")
set_property(TARGET "LANLX3DReader::vtkLANLX3DReader" PROPERTY "INTERFACE_vtk_module_library_name" "vtkLANLX3DReader")
set_property(TARGET "LANLX3DReader::vtkLANLX3DReader" PROPERTY "INTERFACE_vtk_module_headers" "${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkLANLX3DReader.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkLANLX3DReaderModule.h")
set_property(TARGET "LANLX3DReader::vtkLANLX3DReader" PROPERTY "INTERFACE_vtk_module_hierarchy" "${_vtk_module_import_prefix}/lib/paraview/plugins/LANLX3DReader/vtk/hierarchy/LANLX3DReader/vtkLANLX3DReader-hierarchy.txt")
unset(_vtk_module_import_prefix)

==> paraview-5.13.3-7-x86_64.pkg.tar.zst: opt/paraview/lib/cmake/paraview/LANLX3DReader-vtk-module-properties.cmake <==
set(_vtk_module_import_prefix "${CMAKE_CURRENT_LIST_DIR}")
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
set_property(TARGET "LANLX3DReader::vtkLANLX3DReader" PROPERTY "INTERFACE_vtk_module_exclude_wrap" "FALSE")
set_property(TARGET "LANLX3DReader::vtkLANLX3DReader" PROPERTY "INTERFACE_vtk_module_include_marshal" "FALSE")
set_property(TARGET "LANLX3DReader::vtkLANLX3DReader" PROPERTY "INTERFACE_vtk_module_depends" "VTK::FiltersCore")
set_property(TARGET "LANLX3DReader::vtkLANLX3DReader" PROPERTY "INTERFACE_vtk_module_private_depends" "VTK::CommonCore")
set_property(TARGET "LANLX3DReader::vtkLANLX3DReader" PROPERTY "INTERFACE_vtk_module_optional_depends" "")
set_property(TARGET "LANLX3DReader::vtkLANLX3DReader" PROPERTY "INTERFACE_vtk_module_implements" "")
set_property(TARGET "LANLX3DReader::vtkLANLX3DReader" PROPERTY "INTERFACE_vtk_module_implementable" "FALSE")
set_property(TARGET "LANLX3DReader::vtkLANLX3DReader" PROPERTY "INTERFACE_vtk_module_library_name" "vtkLANLX3DReader")
set_property(TARGET "LANLX3DReader::vtkLANLX3DReader" PROPERTY "INTERFACE_vtk_module_headers" "${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkLANLX3DReader.h")
set_property(TARGET "LANLX3DReader::vtkLANLX3DReader" PROPERTY "INTERFACE_vtk_module_hierarchy" "${_vtk_module_import_prefix}/lib/paraview/plugins/LANLX3DReader/vtk/hierarchy/LANLX3DReader/vtkLANLX3DReader-hierarchy.txt")
unset(_vtk_module_import_prefix)
